# IBIS::Driver::Debug.pm
#
# Eugene Eric Kim <eekim@eekim.com>
# http://www.eekim.com/software/perlIBIS/
#
# $Id: Debug.pm,v 1.1 2002/02/26 09:20:48 eekim Exp $
#
# Copyright (c) Eugene Eric Kim 2001-2002.  All rights reserved.
# See COPYING for licensing terms.

package IBIS::Driver::Debug;

use 5.6.1;  # almost certainly works w/ earlier versions; just not tested
$VERSION = '0.2';

=head1 NAME

IBIS::Driver::Debug - Debugging driver for IBIS.pm.

=head1 DESCRIPTION

Called by IBIS.pm.

Generates ASCII text files with mucho debugging information.

=cut

use strict;
use vars qw($VERSION);
use IO::File;

=head1 METHODS

=head2 writeFile()

Outputs map in ASCII text.

 pre:
   $ibisObject must be a valid IBIS object.
   $fileName
 post:
   None.

=cut

sub writeFile {
  my ($ibisObject, $fileName) = @_;

  my $fh = new IO::File ">$fileName";
  # traverse map, starting w/ independent nodes
  my @nodeIds = $ibisObject->getIndependentNodes;
  foreach my $nodeId (@nodeIds) {
    my $node = $ibisObject->getNode($nodeId);
    print $fh '"' . $node->label . '" (' . $node->type . ")\n";
    print $fh '  nid = ' . $node->id . ';' if ($node->id);
    print $fh '  X pos = ' . $node->xPos . ';' if (defined $node->xPos);
    print $fh '  Y pos = ' . $node->yPos . ';' if (defined $node->yPos);
    print $fh '  Pos = ' . $node->pos . ';' if (defined $node->pos);
    print $fh "\n";
    print $fh '  creation date = ' . gmtime($node->creationDate) . "\n"
      if ($node->creationDate);
    print $fh '  modified date = ' . gmtime($node->modificationDate) . "\n"
      if ($node->modificationDate);
    print $fh '  url = ' . $node->url . "\n" if ($node->url);
    print $fh '  detail= ' . $node->detail . "\n" if ($node->detail);
    print $fh "\n";
    &_traverseMap($nodeId, 1, $ibisObject, $fh);
  }
  $fh->close;
}

# private methods

sub _printSpaces {
  my ($indentLevel, $fh) = @_;

  $indentLevel = $indentLevel * 4;
  while ($indentLevel > 0) {
    print $fh " ";
    $indentLevel--;
  }
}

sub _traverseMap {
  my ($nodeId, $indentLevel, $ibisObject, $fh) = @_;

  my @children = $ibisObject->getChildren($nodeId);
  foreach my $childId (@children) {
    my $node = $ibisObject->getNode($childId);
    &_printSpaces($indentLevel, $fh);
    print $fh '"' . $node->label . '" (' . $node->type . ")\n";
    &_printSpaces($indentLevel, $fh);
    print $fh '  nid = ' . $node->id . ';' if ($node->id);
    print $fh '  x pos = ' . $node->xPos . ';' if ($node->xPos);
    print $fh '  y pos = ' . $node->yPos . ';' if ($node->yPos);
    print $fh "\n";
    &_printSpaces($indentLevel, $fh);
    print $fh '  creation date = ' . gmtime($node->creationDate) . "\n"
      if ($node->creationDate);
    &_printSpaces($indentLevel, $fh);
    print $fh '  modified date = ' . gmtime($node->modificationDate) . "\n"
      if ($node->modificationDate);
    &_printSpaces($indentLevel, $fh);
    print $fh '  url = ' . $node->url . "\n" if ($node->url);
#    &_printSpaces($indentLevel, $fh);
#    print $fh '  detail= ' . $node->detail . "\n" if ($node->detail);
    print $fh "\n";
    &_traverseMap($childId, $indentLevel + 1, $ibisObject, $fh);
  }
}

1;

=head1 AUTHOR

Eugene Eric Kim <eekim@eekim.com>

=cut
