# IBIS::Driver::GraphViz.pm
#
# Eugene Eric Kim <eekim@eekim.com>
# http://www.eekim.com/software/perlIBIS/
#
# $Id: GraphViz.pm,v 1.2 2001/08/24 10:29:09 eekim Exp $
#
# Copyright (c) Eugene Eric Kim 2001.  All rights reserved.
# See COPYING for licensing terms.

package IBIS::Driver::GraphViz;

use 5.6.1;  # almost certainly works w/ earlier versions; just not tested
$VERSION = '0.2';

=head1 NAME

IBIS::Driver::GraphViz - GraphViz driver for IBIS.pm.

=head1 DESCRIPTION

Called by IBIS.pm.

Can generate png, ps, svg, fig, dot, or plain files.

=cut

use strict;
use vars qw($VERSION);
use IO::File;
use GraphViz;
use Text::Wrap;

=head1 METHODS

=head2 writeFile()

Outputs map in a variety of file formats.  Determines which format to
use based on file extension.

 pre:
   $ibisObject must be a valid IBIS object.
   $fileName
 post:
   None.

=cut

sub writeFile {
  my ($ibisObject, $fileName) = @_;
  my ($wrappedLabel, $shape, $style, $color, $edgeColor);

  my $fh = new IO::File ">$fileName";
  my $image = GraphViz->new(rankdir=>1, node=>{fontname=>'Times'});
  my $node = $ibisObject->firstNode;
  while ($node) {
    $Text::Wrap::columns = 25;
    $wrappedLabel = Text::Wrap::wrap('', '', $node->label);
    $wrappedLabel =~ s/\n/\\n/gm;
    $wrappedLabel =~ s/"/\\"/g;
    if ($node->type eq 'Issue') {
      $shape = 'box';
      $style = 'bold';
      $color = 'black';
    }
    elsif ($node->type eq 'Argument') {
      $shape = 'box';
      $style = 'dotted';
      $color = 'black';
    }
    elsif ($node->type eq 'MapView') {
      $shape = 'box';
      $style = 'bold';
      $color = 'blue';
    }
    else {
      $shape = 'box';
      $style = 'solid';
      $color = 'black';
    }
    $image->add_node($node->id, label=>$wrappedLabel,
                     shape=>$shape, style=>$style, color=>$color);
    $node = $ibisObject->nextNode;
  }
  my $link = $ibisObject->firstLink;
  while ($link) {
    if ($link->type eq 'Supports') {
      $edgeColor = 'green';
    }
    elsif ($link->type eq 'ObjectsTo') {
      $edgeColor = 'red';
    }
    else {
      $edgeColor = 'black';
    }
    $image->add_edge($link->toNodeId => $link->fromNodeId,
                     color=>$edgeColor, dir=>'back');
    $link = $ibisObject->nextLink;
  }
  if ($fileName =~ /\.png$/i) {
    print $fh $image->as_png;
  }
  elsif ($fileName =~ /\.ps$/i) {
    print $fh $image->as_ps;
  }
  elsif ($fileName =~ /\.dot$/i) {
    print $fh $image->as_text;
  }
  elsif ($fileName =~ /\.fig$/i) {
    print $fh $image->as_fig;
  }
  elsif ($fileName =~ /\.svg$/i) {
    print $fh $image->as_svg;
  }
  else {
    print $fh $image->as_plain;
  }
  $fh->close;
}

1;

=head1 AUTHOR

Eugene Eric Kim <eekim@eekim.com>

=cut
