# IBIS::Driver::QuestMap.pm
#
# Eugene Eric Kim <eekim@eekim.com>
# http://www.eekim.com/software/perlIBIS/
#
# $Id: QuestMap.pm,v 1.5 2002/02/26 09:23:10 eekim Exp $
#
# Copyright (c) Eugene Eric Kim 2001-2002.  All rights reserved.
# See COPYING for licensing terms.

package IBIS::Driver::QuestMap;

use 5.6.1;  # almost certainly works w/ earlier versions; just not tested
$VERSION = '0.2';

=head1 NAME

IBIS::Driver::QuestMap - QuestMap driver for IBIS.pm.

=head1 DESCRIPTION

called by IBIS.pm.

=cut

use strict;
use vars qw($VERSION);
use IO::File;
use Text::Balanced qw(extract_bracketed);

=head1 METHODS

=head2 readFile()

 pre:
   $fileName
 post:
   none



=cut

sub readFile {
  my ($ibisObject, $fileName) = @_;

  my $fh = new IO::File $fileName;
  local $/;
  my $fileString = <$fh>;
  $fh->close;
  my $remainder = $fileString;
  while (1) {
    my $element;
    ($element, $remainder) = &_extractElement($remainder);
    last if (!$element);
    # create and populate node/link
    if ($element->{'type'} =~ /^(\w+)Node$/) {
      $element->{'type'} = $1;
      if ($element->{'type'} eq 'Reference') {
        $element->{'url'} = &_filePathToUrl($element->{'ReferencePath'});
      }
      $ibisObject->createNode(%{$element});
    }
    elsif ($element->{'type'} =~ /^(\w+)Link$/) {
      $element->{'type'} = $1;
      $ibisObject->createLink($element->{'type'}, $element->{'fromID'},
                              $element->{'toID'}, $element->{'id'});
    }
    elsif ($element->{'type'} =~ /^(\w+View)$/) {
      $ibisObject->createNode(%{$element});
    }
  }
}

# private methods

sub _extractElement {
  my $input = shift;
  my (%element);
  my ($field, $rest);

  my ($extracted, $remainder) = extract_bracketed($input, '(")');
  return undef if ($extracted eq '');
  # get element type
  $extracted =~ s/^\(\s*(\w+)//;
  $element{'type'} = $1;
  $extracted =~ s/\s*\)$//;
  # get element fields
  $rest = $extracted;
  do {
    ($field, $rest) = extract_bracketed($rest, '(")');
    if ($field =~ /^\(\s+(\w+)\s+("?.+"?)\s*\)$/s) {
      my $key = $1;
      my $val = $2;
      $key = ($key eq 'ID') ? 'id' : lcfirst($key);
      $val =~ s/^"//;
      $val =~ s/\s+$//;
      $val =~ s/"$//;
      $val =~ s/\\"/"/g;
      $val =~ s/\r//g;
      $element{$key} = $val;
    }
  } while ($field ne '');
  return (\%element, $remainder);
}

sub _filePathToUrl {
  my $path = shift;

  $path =~ s/^([A-Za-z])\:/$1|/;
  return "file://$path";
}

1;

=head1 AUTHOR

Eugene Eric Kim <eekim@eekim.com>

=cut
