# IBIS::Driver::XML.pm
#
# Eugene Eric Kim <eekim@eekim.com>
# http://www.eekim.com/software/perlIBIS/
#
# $Id: XML.pm,v 1.3 2002/02/26 07:33:25 eekim Exp $
#
# Copyright (c) Eugene Eric Kim 2001-2002.  All rights reserved.
# See COPYING for licensing terms.

package IBIS::Driver::XML;

use 5.6.1;  # almost certainly works w/ earlier versions; just not tested
$VERSION = '0.2';

=head1 NAME

IBIS::Driver::XML - XML (Compendium DTD) driver for IBIS.pm.

=head1 DESCRIPTION

Called by IBIS.pm.

Generates XML conforming to Ron van Hoof's Compendium DTD v1.0:

  http://d3e.open.ac.uk/compendium/01/comp-dtd-v1/comp-dtd-v1-t.html

Note that this is a rough cut.  I don't comply completely to the spec,
partially because the spec is not rigorous enough.  You can view my
comments on this at the URL above.

=cut

use strict;
use vars qw($VERSION);
use IO::File;

=head1 METHODS

=head2 writeFile($ibisObject, $fileName)

Serialize IBIS map into XML.

 pre:
   $ibisObject must be a valid IBIS object.
 post:
   None.

=cut

sub writeFile {
  my ($ibisObject, $fileName) = @_;

  my $fh = new IO::File ">$fileName";
  print $fh '<?xml version="1.0"?>', "\n";
  print $fh "<MODEL>\n";
  my $node = $ibisObject->firstNode;
  while ($node) {
    print $fh '  <NODE id="' . $node->id . '"';
    print $fh "\n        type=\"" . $node->type . '"';
    print $fh "\n        label=\"" . &_escapeString($node->label) . '"'
      if ($node->label);
    print $fh "\n        detail=\"" . &_escapeString($node->detail) . '"'
      if ($node->detail);
    print $fh "\n        reference=\"" . $node->url . '"'
      if ($node->url);
    print $fh "\n        author=\"" . &_escapeString($node->author) . '"'
      if ($node->author);
    print $fh "\n        lastModified=\"" . $node->modificationDate . '"'
      if ($node->modificationDate);
    print $fh "\n        created=\"" . $node->creationDate . '"'
      if ($node->creationDate);
    print $fh ">\n";
    print $fh '    <VIEW noderef="' . $node->id . '"';
    print $fh ' XPosition="' . $node->xPos . '"' if ($node->xPos);
    print $fh ' YPosition="' . $node->yPos . '"' if ($node->yPos);
    print $fh ">\n";
    my @links = $ibisObject->getLinksToParents($node->id);
    if (@links) {
      print $fh "      <LINKS>\n";
      foreach my $link (@links) {
        print $fh '        <LINK id="' . $link->id . '"';
        print $fh ' type="' . $link->type . '"';
        print $fh ' to="' . $link->toNodeId . '"';
        print $fh ' direction="to">' . "\n";
      }
      print $fh "      </LINKS>\n";
    }
    print $fh "    </VIEW>\n";
    print $fh "  </NODE>\n";
    $node = $ibisObject->nextNode;
  }
  print $fh "</MODEL>\n";
  $fh->close;
}

# private methods

sub _escapeString {
  my $string = shift;

  $string =~ s/&/&amp;/g;
  $string =~ s/</&lt;/g;
  return $string;
}

1;

=head1 AUTHOR

Eugene Eric Kim <eekim@eekim.com>

=cut
