# IBIS::Link.pm
#
# Eugene Eric Kim <eekim@eekim.com>
# http://www.eekim.com/software/perlIBIS/
#
# $Id: Link.pm,v 1.2 2001/08/24 09:45:29 eekim Exp $
#
# Copyright (c) Eugene Eric Kim 2001.  All rights reserved.
# See COPYING for licensing terms.

package IBIS::Link;

use 5.6.1;  # almost certainly works w/ earlier versions; just not tested
$VERSION = '0.2';

=head1 NAME

IBIS::Link - IBIS Link class.

=head1 SYNOPSIS

 use IBIS::Link;

 $link = new IBIS::Link;
 $link->type('ObjectsTo');
 $link->fromNodeId(1);
 $link->toNodeId(2);

=head1 DESCRIPTION

Link class for the IBIS class.  Enables you to create a link, and
access and modify its fields.

=cut

use strict;
use vars qw($VERSION);

### public methods

=head1 METHODS

=head2 new

Constructor.

=cut

sub new {
  my $this = shift;
  my $self = {};
  bless($self, $this);
  return $self;
}

=head2 Accessors/Mutators

The following methods act as both accessors and mutators for
IBIS::Link objects.  If a parameter is passed, the method acts as a
mutator; otherwise, it acts as an accessor.

    id()
    type()
    fromNodeId()
    toNodeId()

IBIS::Link objects are unaware of where they are instantiated.  See
the IBIS::Node POD for how this affects usage of id().  This also
affects fromNodeID() and toNodeId().  There is no way these methods
can verify that nodes with these IDs actually exist, because
IBIS::Link has no notion of nodes at all!  The IBIS class, on the
other hand, has notions of both nodes and links, and thus, its
createLink() method is capable of determining whether the appropriate
nodes exist or not.

=cut

sub id {
  my $this = shift;

  $this->{'id'} = shift if @_;
  return $this->{'id'};
}

sub type {
  my $this = shift;

  $this->{'type'} = shift if @_;
  return $this->{'type'};
}

sub fromNodeId {
  my $this = shift;

  $this->{'fromNodeId'} = shift if @_;
  return $this->{'fromNodeId'};
}

sub toNodeId {
  my $this = shift;

  $this->{'toNodeId'} = shift if @_;
  return $this->{'toNodeId'};
}

1;

=head1 AUTHOR

Eugene Eric Kim <eekim@eekim.com>

=cut
