# IBIS::Node.pm
#
# Eugene Eric Kim <eekim@eekim.com>
# http://www.eekim.com/software/perlIBIS/
#
# $Id: Node.pm,v 1.4 2002/02/25 00:10:31 eekim Exp $
#
# Copyright (c) Eugene Eric Kim 2001-2002.  All rights reserved.
# See COPYING for licensing terms.

package IBIS::Node;

use 5.6.1;  # almost certainly works w/ earlier versions; just not tested
$VERSION = '0.2';

=head1 NAME

IBIS::Node - IBIS Node class.

=head1 SYNOPSIS

 use IBIS::Node;

 $node = new IBIS::Node;
 $node->type('Issue');
 $node->label('How will California solve its energy crisis?');

 print $node->label . "\n";

=head1 DESCRIPTION

Node class for the IBIS class.  Enables you to create a node, and
access and modify its fields.

=cut

use strict;
use vars qw($VERSION);

### public methods

=head1 METHODS

=head2 new

Constructor.

=cut

sub new {
  my $this = shift;
  my $self = {};
  bless($self, $this);
  return $self;
}

=head2 Accessors/Mutators

The following methods act as both accessors and mutators for
IBIS::Node objects.  If a parameter is passed, the method acts as a
mutator; otherwise, it acts as an accessor.

    id()
    type()
    label()
    detail()
    author()
    url()
    creationDate()
    modificationDate()
    xPos()
    yPos()
    pos()

id() is an interesting method.  IBIS::Node objects are unaware of
where they are instantiated.  When an IBIS object creates an
IBIS::Node object, it stores that node's ID internally.  If you
subsequently use the node's id() method to change the ID, it will
change the node's ID, but it's not smart enough to change the IBIS
object's record of that node's ID.

For example, if you were to run the following code:

  use IBIS;
  $dialogMap = new IBIS;
  $nodeID = $dialogMap->createNode(
      type => 'Issue',
      label => 'Will the Dodgers win the World Series this year?');

you would get the current node ID in, you guessed it, $nodeID.  Let's
pretend that $nodeID is equal to 1.  Now, what if you tried to change
the node's ID to 10 using the id() method?

  $node = $dialogMap->getNode($nodeID);
  $node->id(10);

If you called the id() accessor, it would return "10".  However, if
you tried getting the node with ID 10 from $dialogMap:

  $node2 = $dialogMap->getNode(10);

$node2 would remain undefined, because $dialogMap has no record of a
node with ID 10.

The moral?  Be careful when you use id() as a mutator.  Eventually, I
will probably add a changeNodeId() method to the IBIS class to get
around this problem.

=cut

sub id {
  my $this = shift;

  $this->{'id'} = shift if @_;
  return $this->{'id'};
}

sub type {
  my $this = shift;

  $this->{'type'} = shift if @_;
  return $this->{'type'};
}

sub label {
  my $this = shift;

  $this->{'label'} = shift if @_;
  return $this->{'label'};
}

sub detail {
  my $this = shift;

  $this->{'detail'} = shift if @_;
  return $this->{'detail'};
}

sub author {
  my $this = shift;

  $this->{'author'} = shift if @_;
  return $this->{'author'};
}

sub url {
  my $this = shift;

  $this->{'url'} = shift if @_;
  return $this->{'url'};
}

sub creationDate {
  my $this = shift;

  $this->{'creationDate'} = shift if @_;
  return $this->{'creationDate'};
}

sub modificationDate {
  my $this = shift;

  $this->{'modificationDate'} = shift if @_;
  return $this->{'modificationDate'};
}

sub xPos {
  my $this = shift;

  $this->{'xPos'} = shift if @_;
  return $this->{'xPos'};
}

sub yPos {
  my $this = shift;

  $this->{'yPos'} = shift if @_;
  return $this->{'yPos'};
}

sub pos {
  my $this = shift;

  $this->{'pos'} = shift if @_;
  return $this->{'pos'};
}

1;

=head1 AUTHOR

Eugene Eric Kim <eekim@eekim.com>

=cut
