<?xml version="1.0"?>
<!-- opmltohtml.xsl ==================================================
     Author: Eugene Eric Kim <eekim@eekim.com>
     URL: http://www.eekim.com/software/perlIBIS/

     Version: 0.2
     $Id: opmltohtml.xsl,v 1.5 2002/02/26 05:10:29 eekim Exp $

     Copyright (c) Eugene Eric Kim 2001-2002.  All rights reserved.
     See COPYING for licensing terms.
================================================================== -->

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    version="1.0">

<xsl:output method="html" indent="yes"/>

<!-- ===== global variables ===== -->
<xsl:param name="output"/>  <!-- if "clean", generate clean HTML -->
<xsl:param name="css"/> <!-- use this file for styles instead of style tag -->
<xsl:variable name="version" select="0.1"/>

<!-- ===== construct result set ===== -->
<xsl:template match="/">
  <html>
    <head>
      <title><xsl:value-of select="opml/head/title"/></title>
      <xsl:if test="$css">
      <link href="{$css}" rel="stylesheet" type="text/css"/>
      </xsl:if>
      <style type="text/css">
      <!-- for clean HTML output, you don't need comment tags around the
           CSS styles, because HTML compliant browsers will understand the
           style tags. -->
      <xsl:comment>
           body {
             background-color:#FFFFFF; padding-bottom: 50em;}
           h1 {text-align: center;}
           p.docinfo {text-align: center;}
           p.footer {text-align: right;}
           div.indented {margin-left: 3em;}
           p {margin-top: 4pt; margin-bottom: 4pt;}
           span.issue { font-weight: bold; }
           span.pro { color: green; }
           span.con { color: red; }
           span.detail {
             color: gray;
             font-family: "Helvetica", "Arial", sans-serif;
             font-style: normal;
             font-size: smaller;}
           <!-- purple numbers -->
           <xsl:if test="$css = false()">
           a.hid {
             font-family: "Helvetica", "Arial", sans-serif;
             font-size: x-small;
             font-style: italic;
             font-weight: bold;
             text-decoration: none;
             color: #C8A8FF;}
           a.nid {
             font-family: "Helvetica", "Arial", sans-serif;
             font-style: normal;
             font-weight: bold;
             font-size: x-small;
             text-decoration: none;
             color: #C8A8FF;}
           </xsl:if>
      </xsl:comment>
      </style>
    </head>
    <body>
      <h1><xsl:value-of select="opml/head/title"/></h1>

      <p class="docinfo">
      <xsl:value-of select="opml/head/ownerName"/>
      <xsl:text> </xsl:text>
      <a href="mailto:{opml/head/ownerEmail}">&lt;<xsl:value-of select="opml/head/ownerEmail"/>&gt;</a>
      </p>

      <hr />

      <xsl:apply-templates select="opml/body/outline"/>

      <hr />

      <p class="footer"><i>Document developed using
      <a href="http://www.eekim.com/software/perlIBIS/">perlIBIS</a></i></p>
    </body>
  </html>
</xsl:template>

<xsl:template match="outline">
  <p><a id="nid{@nid}" name="nid{@nid}" />
  <xsl:choose>
    <xsl:when test="@type = 'Issue'">
      <span class="issue"><xsl:value-of select="@text"/></span>
    </xsl:when>
    <xsl:when test="@type = 'Pro'">
      <span class="pro"><xsl:value-of select="@text"/></span>
    </xsl:when>
    <xsl:when test="@type = 'Con'">
      <span class="con"><xsl:value-of select="@text"/></span>
    </xsl:when>
    <xsl:when test="@url = true()">
      <a href="{@url}"><xsl:value-of select="@text"/></a>
    </xsl:when>
    <xsl:otherwise>
      <xsl:value-of select="@text"/>
    </xsl:otherwise>
  </xsl:choose>
  &#xA0;&#xA0;
  <a class="nid" href="#nid{@nid}">(<xsl:value-of select="@nid"/>)</a>
  <xsl:if test="@detail = true()">
  <br/><span class="detail">
  <xsl:value-of select="@detail"/>
  </span>
  </xsl:if>
  </p>
  <!-- check for outline subelements -->
  <xsl:if test="outline = true()">
  <div class="indented">
  <xsl:apply-templates select="outline"/>
  </div>
  </xsl:if>
</xsl:template>

</xsl:stylesheet>
